@@ -1,23 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
 /*
  * gtksourcegutter.c
  * This file is part of gtksourceview
  *
  * Copyright (C) 2009 - Jesse van den Kieboom
  *
- * gtksourceview is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * gtksourceview is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "gtksourcegutter-private.h"
@@ -25,37 +25,6 @@
 #include "gtksourceview-i18n.h"
 #include "gtksourceview-marshal.h"
 
-/**
- * SECTION:gutter
- * @Short_description: Gutter object for #GtkSourceView
- * @Title: GtkSourceGutter
- * @See_also:#GtkSourceView
- *
- * The #GtkSourceGutter object represents the left and right gutters of the text
- * view. It is used by #GtkSourceView to draw the line numbers and category
- * marks that might be present on a line. By packing additional #GtkCellRenderer
- * objects in the gutter, you can extend the gutter with your own custom 
- * drawings.
- *
- * The gutter works very much the same way as cells rendered in a #GtkTreeView.
- * The concept is similar, with the exception that the gutter does not have an
- * underlying #GtkTreeModel. Instead, you should use
- * #gtk_source_gutter_set_cell_data_func to set a callback to fill in any of the
- * cell renderers properties, given the line for which the cell is to be
- * rendered. Renderers are inserted into the gutter at a certain position. The
- * builtin line number renderer is at position 
-
- * #GTK_SOURCE_VIEW_GUTTER_POSITION_LINES (-30) and the marks renderer is at
- * #GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). You can use these values to
- * position custom renderers accordingly. The width of a cell renderer can be
- * specified as either fixed (using
-
- * #gtk_cell_renderer_set_fixed_size) or dynamic, in which case you
- * <emphasis>must</emphasis> set #gtk_source_gutter_set_cell_size_func. This
- * callback is used to set the properties of the renderer such that
- * #gtk_cell_renderer_get_size yields the maximum width of the cell.
- */
-
 #define GTK_SOURCE_GUTTER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTK_TYPE_SOURCE_GUTTER, GtkSourceGutterPrivate))
 
 /* Properties */
@@ -105,7 +74,7 @@ struct _GtkSourceGutterPrivate
 {
 	GtkSourceView *view;
 	GtkTextWindowType window_type;
-	gint size;
+
 	GList *renderers;
 	guint signals[LAST_EXTERNAL_SIGNAL];
 };
@@ -237,8 +206,6 @@ set_view (GtkSourceGutter *gutter,
 {
 	gutter->priv->view = view;
 
-	gutter->priv->size = -1;
-
 	g_object_weak_ref (G_OBJECT (view),
 	                   (GWeakNotify)view_notify,
 	                   gutter);
@@ -308,7 +275,7 @@ revalidate_size (GtkSourceGutter *gutter)
 		gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (gutter->priv->view),
 		                                      gutter->priv->window_type,
 		                                      1);
-		gutter->priv->size = -1;
+		do_redraw (gutter);
 	}
 	else if (window && !gutter->priv->renderers)
 	{
@@ -409,7 +376,7 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 			      3,
 			      GTK_TYPE_CELL_RENDERER,
 			      GTK_TYPE_TEXT_ITER,
-			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
+			      G_TYPE_POINTER);
 
 	/**
 	 * GtkSourceGutter::query-tooltip:
@@ -442,8 +409,6 @@ static void
 gtk_source_gutter_init (GtkSourceGutter *self)
 {
 	self->priv = GTK_SOURCE_GUTTER_GET_PRIVATE (self);
-
-	self->priv->size = -1;
 }
 
 static gint
@@ -717,6 +682,7 @@ gtk_source_gutter_queue_draw (GtkSourceGutter *gutter)
 	revalidate_size (gutter);
 }
 
+/* Callbacks */
 static gint
 calculate_size (GtkSourceGutter  *gutter,
                 Renderer         *renderer)
@@ -878,33 +844,12 @@ on_view_expose_event (GtkSourceView   *view,
 	text_view = GTK_TEXT_VIEW (view);
 	sizes = g_array_new (FALSE, FALSE, sizeof (gint));
 
-	/* This is fairly ugly, but we could not find a better way to
-	 * do it: renderers could have changed size and they do not have
-	 * a way to signal it. So on expose we revalidate the size and
-	 * requeue another expose.
-	 * To see if the size has changed we test the size of only the
-	 * gutter itself since the full border window size is not under
-	 * our control (see e.g bug #589382).
-	 * This also means that if the user manually forces the
-	 * border_window_size to a value smaller than the gutter, things
-	 * will not be drawn properly. */
 	size = calculate_sizes (gutter, sizes);
-	if (gutter->priv->size != size)
+
+	if (gtk_text_view_get_border_window_size (text_view, gutter->priv->window_type) != size)
 	{
-
-		gint border_size;
-
-		border_size = gtk_text_view_get_border_window_size (text_view, gutter->priv->window_type);
-
-		if (gutter->priv->size < 0)
-			border_size += size;
-		else
-			border_size = MAX (0, border_size - gutter->priv->size) + size;
-
-		gutter->priv->size = size;
-
 		/* Will trigger a new expose */
-		gtk_text_view_set_border_window_size (text_view, gutter->priv->window_type, border_size);
+		gtk_text_view_set_border_window_size (text_view, gutter->priv->window_type, size);
 	}
 	else
 	{
@@ -1190,18 +1135,7 @@ on_view_button_press_event (GtkSourceView    *view,
 		g_free (path);
 		do_redraw (gutter);
 
-		/* WARNING, DANGER, DANGER:
-		 * FIXME: this is really just a hack because we lack a return
-		 * value in the CELL_ACTIVATED signal, so handlers of cell
-		 * activating have no way to consume the button event. A left
-		 * click in the gutter will by default remove the selection
-		 * in the textview, which is bad because we implement some
-		 * selection stuff in gtksourceview when clicking on the line
-		 * renderer. Anyway, for 3.0 we should change the
-		 * cell-activated signal to allow a return value and remove
-		 * this hack
-		 */
-		return ret || event->button == 1;
+		return ret;
 	}
 
 	return FALSE;
